How-tos
=======


.. toctree::
   :maxdepth: 2

   move_axes
   nus

Other planned topics
--------------------

* Add text

* NUS data

* Gridspec

* How to make a legend for a figure and not axes? (feat. ``cleanup_figure()``)

* How to reduce boilerplate code?

